### Tests
{links}

#### Setup
Before we can run our examples we should get a bit of setup out of the way.
Since these examples were harvested from the unit tests not all pieces
will be necessary for all situations.
```python
{setup}
```

All tests are wrapped in a test class
```python
{class_setup}
```
{tests}